AlekSIS (School Information System) — App Discourse (Integration with the Discourse discussion forum)
=====================================================================================================

AlekSIS
-------

This is an application for use with the `AlekSIS®`_ platform.

Features
--------

The author of this app did not describe it yet.

Licence
-------

::

  Copyright © 2022 Dominik George <dominik.george@teckids.org>

  Licenced under the EUPL, version 1.2 or later

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

Trademark
---------

AlekSIS® is a registered trademark of the AlekSIS open source project, represented
by Teckids e.V. Please refer to the `trademark policy`_ for hints on using the trademark
AlekSIS®.

.. _AlekSIS®: https://edugit.org/AlekSIS/AlekSIS
.. _European Union Public Licence: https://eupl.eu/
.. _trademark policy: https://aleksis.org/pages/about
